@@ -37,18 +37,9 @@ from .download import download_users as download_users_
 from .download import download_users_update
 from .download import read_cookies
 from .download import write_cookies
-
-
-class MalformedCommand(Exception):
-    pass
-
-
-class UnknownCommand(Exception):
-    pass
-
-
-class MultipleInstances(Exception):
-    pass
+from .exceptions import MalformedCommand
+from .exceptions import MultipleInstances
+from .exceptions import UnknownCommand
 
 
 def check_process(process: str):
@@ -83,7 +74,7 @@ def raiser(e: Exception) -> Callable:
     return inner
 
 
-def docstring_parameter(*args, **kwargs):
+def docstring_format(*args, **kwargs):
     def inner(obj: {__doc__}) -> {__doc__}:
         obj.__doc__ = obj.__doc__.format(*args, **kwargs)
         return obj
@@ -109,7 +100,7 @@ def parse_args(args_raw: Iterable[str]) -> tuple[dict[str, str], list[str]]:
     args: list[str] = []
 
     for i, arg in enumerate(args_raw):
-        if match(r"\w+=\w+", arg):
+        if match(r"^[^ ]+=[^ ]*$", arg):
             opts.append(arg)
         elif arg == "--":
             args.extend(args_raw[i + 1:])
@@ -204,9 +195,8 @@ def config_list(db: FADatabase, *_rest):
         Prints a list of stored settings.
     """
 
-    for c in read_cookies(db):
-        print(f"cookie {c['name']}:", c['value'])
-    print("files folder:", db.settings["FILESFOLDER"])
+    config_cookies(db)
+    config_files_folder(db)
 
 
 def config_cookies(db: FADatabase, *args: str):
@@ -249,7 +239,7 @@ def config_files_folder(db: FADatabase, *args: str):
     """
 
     if not args:
-        print("files folder:", db.settings["FILESFOLDER"])
+        print(f"files folder: {(ff := db.settings['FILESFOLDER'])} ({db.database_path / ff})")
     elif len(args) == 1:
         print(f"Moving files folder to {args[0]}")
         db.move_files_folder(args[0])
@@ -443,6 +433,7 @@ def database_info(db: FADatabase, *_rest):
         Show database information, statistics and version.
     """
 
+    print("Location    :", db.database_path)
     print("Size        :", f"{getsize(db.database_path) / 1e6:.1f}MB")
     print("Users       :", len(db.users))
     print("Submissions :", len(db.submissions))
@@ -493,10 +484,11 @@ def database_search(table: FADatabaseTable, print_func: Callable, *args: str):
         print(dumps(results))
     else:
         print_func(results)
-        print(f"Found {len(results)} users")
+        print(f"Found {len(results)} {table.table.lower()}")
 
 
-@docstring_parameter(database_search.__doc__.format("users"))
+@docstring_format("users")
+@docstring_format(database_search.__doc__)
 def database_search_users(db: FADatabase, *args: str):
     """
     {0}
@@ -508,7 +500,8 @@ def database_search_users(db: FADatabase, *args: str):
     database_search(db.users, print_users, *args)
 
 
-@docstring_parameter(database_search.__doc__.format("submissions"))
+@docstring_format("submissions")
+@docstring_format(database_search.__doc__)
 def database_search_submissions(db: FADatabase, *args: str):
     """
     {0}
@@ -523,7 +516,8 @@ def database_search_submissions(db: FADatabase, *args: str):
     database_search(db.submissions, print_items, *args)
 
 
-@docstring_parameter(database_search.__doc__.format("journals"))
+@docstring_format("journals")
+@docstring_format(database_search.__doc__)
 def database_search_journals(db: FADatabase, *args: str):
     """
     {0}
@@ -695,7 +689,7 @@ def database_remove_journals(db: FADatabase, *args: str):
     db.commit()
 
 
-@docstring_parameter(__server_version__)
+@docstring_format(__server_version__)
 def database_server(db: FADatabase, *args: str):
     """
     USAGE
@@ -715,11 +709,23 @@ def database_server(db: FADatabase, *args: str):
     """
 
     db.close()
+    database_path, db = db.database_path, None
     opts, _ = parse_args(args)
-    server(db.database_path, host=opts.get("host", "0.0.0.0"), port=int(opts.get("port", 8080)))
+    server(database_path, host=opts.get("host", "0.0.0.0"), port=int(opts.get("port", 8080)))
 
 
 def database_merge_copy(db: FADatabase, merge: bool = True, *args):
+    """
+    USAGE
+        falocalrepo database {0} <path> [<table1>.<param1>=<value1> ...
+                    <tableN>.<paramN>=<valueN>]
+
+    ARGUMENTS
+        <path>  Path to second database file
+        <table> One of users, submissions, journals
+        <param> Search parameter
+        <value> Value of the parameter
+    """
     if not args:
         raise MalformedCommand("copy needs at least a database argument")
 
@@ -739,17 +745,11 @@ def database_merge_copy(db: FADatabase, merge: bool = True, *args):
         print("Done")
 
 
+@docstring_format("merge")
+@docstring_format(database_merge_copy.__doc__)
 def database_merge(db: FADatabase, *args: str):
     """
-    USAGE
-        falocalrepo database merge <path> [<table1>.<param1>=<value1> ...
-                    <tableN>.<paramN>=<valueN>]
-
-    ARGUMENTS
-        <path>  Path to second database file
-        <table> One of users, submissions, journals
-        <param> Search parameter
-        <value> Value of the parameter
+    {0}
 
     DESCRIPTION
         Merge selected entries from a second database to the main database (the one
@@ -771,17 +771,11 @@ def database_merge(db: FADatabase, *args: str):
     database_merge_copy(db, True, *args)
 
 
+@docstring_format("copy")
+@docstring_format(database_merge_copy.__doc__)
 def database_copy(db: FADatabase, *args: str):
     """
-    USAGE
-        falocalrepo database copy <path> [<table1>.<param1>=<value1> ...
-                    <tableN>.<paramN>=<valueN>]
-
-    ARGUMENTS
-        <path>  Path to second database file
-        <table> One of users, submissions, journals
-        <param> Search parameter
-        <value> Value of the parameter
+    {0}
 
     DESCRIPTION
         Copy selected entries to a new or existing database. To select entries, use
@@ -815,7 +809,7 @@ def database_clean(db: FADatabase, *_rest):
     db.vacuum()
 
 
-@docstring_parameter(__database_version__)
+@docstring_format(__database_version__)
 def database_upgrade(db: FADatabase, *_rest):
     """
     USAGE
@@ -828,7 +822,7 @@ def database_upgrade(db: FADatabase, *_rest):
     db.upgrade()
 
 
-@docstring_parameter(__database_version__)
+@docstring_format(__database_version__)
 def database(db: FADatabase, comm: str = "", *args: str):
     """
     USAGE
@@ -898,7 +892,7 @@ def database(db: FADatabase, comm: str = "", *args: str):
     }.get(comm, raiser(UnknownCommand(f"database {comm}")))(db, *args)
 
 
-@docstring_parameter(__version__, __database_version__, __server_version__, __faapi_version__)
+@docstring_format(__version__, __database_version__, __server_version__, __faapi_version__)
 def console(comm: str = "", *args: str) -> None:
     """
     falocalrepo: {0}
